#define dev pre
%define rel		2

Name:			nanovna-saver
Version:		0.6.8
Release:		%mkrel %{?dev:0.%{dev}.}%{rel}
Summary:		Connects to a NanoVNA to display, manipulate and save data
Group:			Communications/Radio
License:		GPLv3
Url:			https://github.com/mihtjel/nanovna-saver
Source0:		https://github.com/mihtjel/%{name}/archive/v%{version}%{?dev:-%{dev}}/%{name}-%{version}%{?dev:-%{dev}}.tar.gz
# Use ./mk-tar <tag> in SOURCES dir to get full sources (github generated tarball will NOT build)
Source1:		mk-tar

# Hack to allow higher versions of python runtime requires - reported upstream
Patch0:			loosen_deps.patch

BuildRequires:	git
BuildRequires:	libxml2-python3
BuildRequires:	python3-cython
BuildRequires:	python3-devel
BuildRequires:	python3-numpy
BuildRequires:	python3-qt6-devel
BuildRequires:	python3-scipy
BuildRequires:	python3-serial
BuildRequires:	python3-setuptools-scm

Requires:		python3-qt6-core
Requires:		python3-qt6-gui
Requires:		python3-qt6-widgets
Requires(pre):	shadow-utils

BuildArch:		noarch

%description
A multi-platform tool to save Touchstone files from the NanoVNA. 
Sweep frequency spans in segments to gain more than 101 data points,
and display and analyze the resulting data.

Current features:
*   Reading data from a NanoVNA
*   Splitting a frequency range into multiple segments to increase resolution
    (tried up to >10k points)
*   Zoom into frequency displays to examine details
*   Averaging data for better results particularly at higher frequencies
*   Displaying data on multiple chart types, such as Smith, LogMag, Phase and
    VSWR-charts, for both S11 and S21
*   Displaying markers, and the impedance, VSWR, Q, equivalent
    capacitance/inductance etc. at these locations
*   Displaying customizable frequency bands as reference, for example amateur
    radio bands
*   Exporting and importing 1-port and 2-port Touchstone files
    TDR function (measurement of cable length)
*   Display of both an active and a reference trace
*   Live updates of data from the NanoVNA, including for multi-segment sweeps
*   In-application calibration, including compensation for non-ideal 
    calibration standards
*   Customizable display options, including "dark mode"
*   Exporting images of plotted values

%pre
usermod -G dialout -a $(users|cut -d' ' -f1) ||:

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%py3_build

%install
%py3_install

# Make binary lower case and use name
mv %{buildroot}%{_bindir}/NanoVNASaver-gui %{buildroot}%{_bindir}/%{name}
rm -f %{buildroot}%{_bindir}/NanoVNASaver

# Remove upstream desktop file with camel names
rm -f %{buildroot}%{_datadir}/applications/NanoVNASaver.desktop

# Fix icon name
mkdir -p %{buildroot}%{_iconsdir}/hicolor/48x48/apps/
install -m 644 icon_48x48.png %{buildroot}%{_iconsdir}/hicolor/48x48/apps/%{name}.png

# Desktop file
cat>%{name}.desktop<<EOF
[Desktop Entry]
Name=NanoVNA-Saver
GenericName=NanoVNA-Saver
Exec=%{name}
Icon=%{name}
Terminal=false
Type=Application
Categories=Science;Engineering;Electronics;
Version=1.0
Comment=Connect to NanoVNA
EOF

desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{name}.desktop

cat > README.urpmi <<EOF
You will need to log out and log back in to your system
after installing NanoVNA-Saver before using it for the
first time.

Then connect your NanoVNA to a USB port and switch it on
before running NanoVNA-Saver from the menu.

It is located under the 'Sciences' section of the main menu.
EOF

%files
%doc README.urpmi
%{_bindir}/%{name}
%{python3_sitelib}/NanoVNASaver/
%{python3_sitelib}/NanoVNASaver-*
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/48x48/apps/%{name}.png


%changelog
* Fri Jan 03 2025 barjac <barjac> 0.6.8-2.mga10
+ Revision: 2135279
- patch to fix runtime requires

* Fri Dec 20 2024 barjac <barjac> 0.6.8-1.mga10
+ Revision: 2126531
- new version 0.6.8
- remove unneeded BRs
- fix camel name binary
- sort BRs for clarity

* Tue Nov 12 2024 barjac <barjac> 0.6.5-1.mga10
+ Revision: 2114316
- new version 0.6.5

* Tue Aug 13 2024 barjac <barjac> 0.6.4-1.mga10
+ Revision: 2086429
- new version 0.6.4
- add mk-tar script to create tarball as github tarball is incomplete

* Tue Jan 16 2024 barjac <barjac> 0.6.3-1.mga10
+ Revision: 2031385
- new version 0.6.3
- move to qt6
- clean spec and remove docs

* Sun Apr 23 2023 barjac <barjac> 0.5.5-1.mga9
+ Revision: 1954578
- new version 0.5.5

* Mon Jan 30 2023 barjac <barjac> 0.5.4-1.mga9
+ Revision: 1937124
- new version 0.5.4
- work around changed paths and filenames upstream

* Fri Sep 16 2022 barjac <barjac> 0.5.3-1.mga9
+ Revision: 1889141
- new version 0.5.3

* Fri Sep 09 2022 barjac <barjac> 0.5.1-1.mga9
+ Revision: 1886149
- new version 0.5.1
- drop obsolete patch

* Sat Apr 09 2022 barjac <barjac> 0.4.0-1.mga9
+ Revision: 1848344
- new version 0.4.0
- remove obsolete patch
- patch to allow use of python3-numpy-1.22.0
- new version 0.4.0
- remove obsolete patch
- patch to allow use of python3-numpy-1.22.0

* Wed Apr 06 2022 umeabot <umeabot> 0.3.10-3.mga9
+ Revision: 1845946
- Mageia 9 Mass Rebuild

* Tue Mar 01 2022 mrambo3501 <mrambo3501> 0.3.10-2.mga9
+ Revision: 1786834
- rebuild for python-3.10

* Sun Jan 23 2022 barjac <barjac> 0.3.10-1.mga9
+ Revision: 1769545
- new version 0.3.10

* Tue Mar 23 2021 barjac <barjac> 0.3.9-0.pre.4.mga9
+ Revision: 1708391
- rebuild for py3.9

* Tue Mar 16 2021 daviddavid <daviddavid> 0.3.9-0.pre.3.mga9
+ Revision: 1703860
- install the desktop icon in '/usr/share/icons/hicolor/48x48/apps/'

* Tue Mar 16 2021 daviddavid <daviddavid> 0.3.9-0.pre.2.mga9
+ Revision: 1703769
- add minimal python3-qt5 dependencies (mga#28605)

* Sun Jan 03 2021 barjac <barjac> 0.3.9-0.pre.1.mga8
+ Revision: 1668375
- new version 0.3.9-pre

* Sat Oct 10 2020 barjac <barjac> 0.3.8-0.pre.2.mga8
+ Revision: 1633105
- allow python-scipy 1.5
- upstream bug https://github.com/NanoVNA-Saver/nanovna-saver/issues/332
- re-format %%description

* Wed Aug 26 2020 barjac <barjac> 0.3.8-0.pre.1.mga8
+ Revision: 1619055
- new version 0.3.8-pre
- modify spec to allow pre and rc versions

* Tue Jul 14 2020 barjac <barjac> 0.3.6-1.mga8
+ Revision: 1605833
- new version 0.3.6

* Sun Jul 05 2020 barjac <barjac> 0.3.4-1.mga8
+ Revision: 1602066
- new version 0.3.4

* Tue Jun 30 2020 barjac <barjac> 0.3.3-1.mga8
+ Revision: 1600793
- new version 0.3.3

* Tue Jun 30 2020 barjac <barjac> 0.3.2-1.mga8
+ Revision: 1600559
- new version 0.3.2

* Wed Feb 19 2020 umeabot <umeabot> 0.2.2-2.mga8
+ Revision: 1543041
- Mageia 8 Mass Rebuild

* Sun Jan 12 2020 barjac <barjac> 0.2.2-1.mga8
+ Revision: 1477629
- new version 0.2.2

* Sat Jan 04 2020 barjac <barjac> 0.2.1-0.1.mga8
+ Revision: 1476044
- new version 0.2.1
- added new files

* Tue Nov 12 2019 barjac <barjac> 0.2.0-1.mga8
+ Revision: 1459693
- new version 0.2.0
- spec tidy
- add line to description

* Tue Nov 05 2019 barjac <barjac> 0.1.5-1.mga8
+ Revision: 1458267
- new version 0.1.5
- remove patch fixed upstream

* Wed Oct 23 2019 barjac <barjac> 0.1.4-1.mga8
+ Revision: 1455371
- new version 0.1.4

* Tue Oct 22 2019 barjac <barjac> 0.1.3-2.mga8
+ Revision: 1455080
- Use upstream icon
- remove some white space

* Sun Oct 20 2019 barjac <barjac> 0.1.3-1.mga8
+ Revision: 1454742
- new package

